@@ -102,12 +102,15 @@ static const gchar *test_lines[] = {
   "fakesrc name=100 fakesink name=101 silent=true 100. ! 101.", /* linking with named reference on both sides */
   "fakesrc ! 1__dentity ! fakesink silent=true",        /* using a freshly registered element type */
   "fakesrc ! tee name=t  t.src_12 ! queue ! fakesink  t.src_3 ! queue ! fakesink",
-  "fakesrc name=foo name=fin  fin. ! fakesink", /* testing assignments are executed in correct order (left-to-right) */
   "( fakesrc ) ! fakesink",     /* ghostPad creation on-the-fly, infix notation link */
   "( fakesrc name=dasrc ) dasrc. ! fakesink",   /* ghostPad creation on-the-fly, named link */
 /*  "(name=mabin fakesrc) mabin. ! fakesink", FIXME: linking to named bin does not work yet */
 /*  "(name=mabin name=yoyo fakesrc) yoyo. ! fakesink", FIXME: linking to named bin does not work yet  */
   "deepsrc. ! fakesink fakesrc  ! ( identity ! ( identity ! (  identity name=deepsrc ) ) )",    /* deep name resolution, multilevel ghostpad creation */
+  "fakesrc : fakesink",         /* linking all matching pads */
+  "fakesrc : video/x-all : fakesink",   /* linking all matching pads with filter */
+  "fakesrc ! video/x-all : fakesink",   /* linking all matching pads with filter */
+  "fakesrc : video/x-all ! fakesink",   /* linking all matching pads with filter */
   NULL
 };
 
@@ -125,8 +128,8 @@ GST_START_TEST (test_launch_lines)
   fail_unless (efac != NULL);
   type = gst_element_factory_get_element_type (efac);
   fail_unless (type != 0);
-  g_object_unref (efac);
-  g_object_unref (efac);
+  gst_object_unref (efac);
+  gst_object_unref (efac);
   fail_unless (gst_element_register (NULL, "1__dentity", GST_RANK_NONE, type));
 
   for (s = test_lines; *s != NULL; s++) {
@@ -317,9 +320,9 @@ static const gchar *expected_failures[] = {
   "fakesrc ! video/raw,format=(antwerp)monkeys ! fakesink silent=true",
   /* checks: Empty pipeline is invalid */
   "",
-  /* checks: Link without sink element failes */
+  /* checks: Link without sink element fails */
   "fakesrc ! ",
-  /* checks: Link without src element failes */
+  /* checks: Link without src element fails */
   " ! fakesink silent=true",
   /* checks: Source URI for which no element exists is a failure */
   "borky://fdaffd ! fakesink silent=true",
@@ -362,8 +365,6 @@ static const gchar *expected_failures[] = {
   "fakesrc ! fakesink s.ch1",
   /* unlinked src/sink URI */
   "http://eff.org fakesrc ! fakesink",
-  /* catch assignments evaluated in wrong order */
-  "fakesrc name=ss name=st  ss. ! fakesink",
   /* unbalanced brackets */
   "(", ")", ")  (",
   /* END: */
@@ -375,6 +376,7 @@ GST_START_TEST (expected_to_fail_pipes)
   const gchar **s;
 
   for (s = expected_failures; *s != NULL; s++) {
+    GST_ERROR ("Running %s", *s);
     expected_fail_pipe (*s);
   }
 }
@@ -415,6 +417,7 @@ run_delayed_test (const gchar * pipe_str, const gchar * peer,
 {
   GstElement *pipe, *src, *sink;
   GstPad *srcpad, *sinkpad, *peerpad = NULL;
+  GstStateChangeReturn ret;
 
   pipe = setup_pipeline (pipe_str);
 
@@ -430,11 +433,22 @@ run_delayed_test (const gchar * pipe_str, const gchar * peer,
 
   /* Set the state to PAUSED and wait until the src at least reaches that
    * state */
-  fail_if (gst_element_set_state (pipe, GST_STATE_PAUSED) ==
-      GST_STATE_CHANGE_FAILURE);
+  ret = gst_element_set_state (pipe, GST_STATE_PAUSED);
 
-  fail_if (gst_element_get_state (src, NULL, NULL, GST_CLOCK_TIME_NONE) ==
-      GST_STATE_CHANGE_FAILURE);
+  if (expect_link) {
+    fail_if (ret == GST_STATE_CHANGE_FAILURE);
+  } else {
+    fail_unless (ret == GST_STATE_CHANGE_FAILURE
+        || ret == GST_STATE_CHANGE_ASYNC);
+  }
+
+  ret = gst_element_get_state (pipe, NULL, NULL, GST_CLOCK_TIME_NONE);
+
+  if (expect_link) {
+    fail_if (ret == GST_STATE_CHANGE_FAILURE);
+  } else {
+    fail_unless (ret == GST_STATE_CHANGE_FAILURE);
+  }
 
   /* Now, the source element should have a src pad, and if "peer" was passed, 
    * then the src pad should have gotten linked to the 'sink' pad of that 
@@ -654,6 +668,24 @@ GST_START_TEST (test_missing_elements)
 
 GST_END_TEST;
 
+GST_START_TEST (test_preset)
+{
+  GstElement *element;
+  GError *err = NULL;
+
+  /* missing preset */
+  element =
+      gst_parse_launch
+      ("fakesrc ! identity @preset=\"Wrong preset\" ! fakesink", &err);
+  fail_unless (err != NULL, "expected error");
+  fail_unless_equals_int (err->code, GST_PARSE_ERROR_COULD_NOT_SET_PROPERTY);
+  fail_unless (element != NULL, "Doesn't NULL return without FATAL_ERRORS");
+  gst_clear_object (&element);
+  g_clear_error (&err);
+}
+
+GST_END_TEST;
+
 GST_START_TEST (test_flags)
 {
   GstElement *element;
@@ -718,6 +750,7 @@ parse_suite (void)
   tcase_add_test (tc_chain, test_flags);
   tcase_add_test (tc_chain, test_missing_elements);
   tcase_add_test (tc_chain, test_parsing);
+  tcase_add_test (tc_chain, test_preset);
   return s;
 }
 
